==> HostCMS.Free_6.7.tar.gz: modules/shop/delivery/condition/i18n/ru.php <==
<?php
/**
 * Online shop.
 *
 * @package HostCMS
 * @version 6.x
 * @author Hostmake LLC
 * @copyright © 2005-2017 ООО "Хостмэйк" (Hostmake LLC), http://www.hostcms.ru
 */
return array(
	'model_name' => 'Условия доставки',
	'show_cond_of_delivery_title' => "Список условий доставки типа доставки \"%s\"",
	'show_cond_of_delivery' => "Условия доставки",
	'show_cond_of_delivery_add' => "Добавить",
	'show_cond_of_delivery_import' => "Импорт",
	'cond_of_delivery_edit_form_title' => "Редактирование информации об условии доставки",
	'cond_of_delivery_add_form_title' => "Добавление информации об условии доставки",
	'name' => "<acronym title=\"Название условия доставки\">Название</acronym>",
	'active' => "<acronym title=\"Активность условия доставки\">Активно</acronym>",	
	'delivery_time' => "<acronym title=\"Период времени, в течение которого выполняется доставка\">Сроки доставки</acronym>",
	'shop_country_id' => "<acronym title=\"Страна доставки\">Страна</acronym>",
	'shop_country_location_id' => "<acronym title=\"Местоположение доставки\">Местоположение</acronym>",
	'shop_country_location_city_id' => "<acronym title=\"Город доставки\">Город</acronym>",
	'shop_country_location_city_area_id' => "<acronym title=\"Район доставки\">Район</acronym>",
	'min_weight' => "Вес заказа от (%s), при указании 0 &mdash; минимальный вес заказа не ограничен",
	'max_weight' => "Вес заказа до (%s), при указании 0 &mdash; максимальный вес заказа не ограничен",
	'min_price' => "Цена заказа от, при указании 0 &mdash; минимальная цена заказа не ограничена",
	'max_price' => "Цена заказа до, при указании 0 &mdash; максимальная цена заказа не ограничена",
	'description' => "<acronym title=\"Описание условия доставки\">Описание</acronym>",
	'price' => "<acronym title=\"Цена доставки\">Цена доставки</acronym>",
	'shop_tax_id' => "Налог",
	'cond_of_delivery_tab' => "Условия доставки",
	'shop_delivery_id' => "<acronym title=\"Тип доставки, к которому относится условие доставки\">Тип доставки, к которому относится условие доставки</acronym>",
	'id' => 'Идентификатор',
	'edit_success' => "Данные об условиях доставки успешно добавлены!",
	'shop_measure_not_checked' => "Единица измерения не указана для магазина",
	'markDeleted_success' => "Данные об условиях доставки успешно удалены!",
	'import_button' => "Импорт",
	'import_price_list_file_type' => "<acronym title=\"Выберите файл с компьютера\">Выберите файл с компьютера</acronym>",
	'msg_import_file' => 'Не указан файл импорта!',
	'import_delivery_result' => "Было проимпортировано %s элементов",
	'delete_success' => 'Элемент удален!',
	'undelete_success' => 'Элемент восстановлен!',
	'changeStatus_success' => "Информация успешно изменена",	
	'marking' => "<acronym title=\"Артикул доставки\">Артикул доставки</acronym>",
	'sorting' => "<acronym title=\"Порядок сортировки\">Порядок сортировки</acronym>",
	'apply_success' => "Информация успешно изменена",
	'inverted' => "Не"
);

==> HostCMS.Free_7.0.tar.gz: modules/shop/delivery/condition/i18n/ru.php <==
<?php

return array(
	'model_name' => 'Условия доставки',
	'show_cond_of_delivery_title' => "Список условий доставки типа доставки \"%s\"",
	'show_cond_of_delivery' => "Условия доставки",
	'show_cond_of_delivery_add' => "Добавить",
	'show_cond_of_delivery_import' => "Импорт",
	'cond_of_delivery_edit_form_title' => 'Редактирование информации об условии доставки "%s"',
	'cond_of_delivery_add_form_title' => "Добавление информации об условии доставки",
	'name' => "Название",
	'active' => "Активно",
	'delivery_time' => "Сроки доставки",
	'shop_country_id' => "Страна",
	'shop_country_location_id' => "Местоположение",
	'shop_country_location_city_id' => "Город",
	'shop_country_location_city_area_id' => "Район",
	'min_weight' => "Вес заказа от (%s), при указании 0 &mdash; минимальный вес заказа не ограничен",
	'max_weight' => "Вес заказа до (%s), при указании 0 &mdash; максимальный вес заказа не ограничен",
	'min_price' => "Цена заказа от, при указании 0 &mdash; минимальная цена заказа не ограничена",
	'max_price' => "Цена заказа до, при указании 0 &mdash; максимальная цена заказа не ограничена",
	'description' => "Описание",
	'price' => "Цена доставки",
	'shop_tax_id' => "Налог",
	'cond_of_delivery_tab' => "Условия доставки",
	'shop_delivery_id' => "Тип доставки, к которому относится условие доставки",
	'id' => 'Идентификатор',
	'edit_success' => "Данные об условиях доставки успешно добавлены!",
	'copy_success' => "Информация успешно скопирована!",
	'shop_measure_not_checked' => "Единица измерения не указана для магазина",
	'markDeleted_success' => "Данные об условиях доставки успешно удалены!",
	'import_button' => "Импорт",
	'import_price_list_file_type' => "Выберите файл с компьютера",
	'msg_import_file' => 'Не указан файл импорта!',
	'import_delivery_result' => "Было проимпортировано %s элементов",
	'delete_success' => 'Элемент удален!',
	'undelete_success' => 'Элемент восстановлен!',
	'changeStatus_success' => "Информация успешно изменена",
	'marking' => "Артикул доставки",
	'sorting' => "Порядок сортировки",
	'apply_success' => "Информация успешно изменена",
	'inverted' => "Не",
	'time_from' => "Время заказа с, при указании 00:00:00 &mdash; время не ограничено",
	'time_to' => "Время заказа до, при указании 00:00:00 &mdash; время не ограничено",
);
